import { motion } from "framer-motion";
import { useContext, useState } from "react";
import { CourseDetailContext } from "./CourseDetailContext";
import { CourseSyllabus } from "./CourseSyllabus";
import { CourseDetailContent } from "./CourseDetailContent";
import CourseVideoPage from "./CourseVideoPage";

export default function CourseDetailLayout() {
	const { course, selectedLectureId, isLoading, setSelectedLectureId } =
		useContext(CourseDetailContext);

	const handleLectureClick = (lectureId: string) => {
		setSelectedLectureId(lectureId);
	};
	const [isSyllabusOpen, setIsSyllabusOpen] = useState(false);
	return (
		<div className="relative">
			{/* 主内容区域 */}
			<motion.div
				animate={{
					width: isSyllabusOpen ? "66.666667%" : "100%",
				}}
				transition={{ type: "spring", stiffness: 300, damping: 30 }}
				className="relative">
				<CourseVideoPage
					course={course}
					isLoading={isLoading}
					videoSrc="http://localhost/uploads/2025/01/08/SvWL48Gjg0/stream/index.m3u8"
					videoPoster="http://localhost/uploads/2025/01/08/SvWL48Gjg0/cover.webp"
				/>
			</motion.div>

			{/* 课程大纲侧边栏 */}
			<CourseSyllabus
				sections={course?.sections || []}
				onLectureClick={handleLectureClick}
				isOpen={isSyllabusOpen}
				onToggle={() => setIsSyllabusOpen(!isSyllabusOpen)}
			/>
		</div>
	);
}
